@@ -11,7 +11,6 @@ __author__ = 'TROUVERIE Joachim'
 import os.path
 from clize import clize, run
 from datetime import datetime
-from urlparse import urljoin
 from werkzeug.contrib.atom import AtomFeed
 
 from microbe import app, pages, babel
@@ -20,7 +19,7 @@ from forms import CommentForm, SearchForm
 from utils import get_objects_for_page, create_pagination
 from search import search_query, init_index
 
-from flask import g, request, abort 
+from flask import g, request, abort, url_for 
 from flask.ext.babel import format_datetime, lazy_gettext
 from flask.ext.themes2 import render_theme_template
 
@@ -227,7 +226,7 @@ def feed() :
                 unicode(post.summary),
                 content_type = 'html',
                 author = post.meta.get('author', ''),
-                url = urljoin(request.url_root, post.path),
+                url = url_for('page', path = post.path, _external = True),
                 updated = post.published)
     return feed.get_response()
 
